"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _initReplicationStateTable = _interopRequireDefault(require("./init-replication-state-table"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getReplicationState = async pool => {
  const {
    executeStatement,
    escapeId
  } = pool;
  const replicationStateTableName = await (0, _initReplicationStateTable.default)(pool);
  const rows = await executeStatement(`SELECT "Status", "StatusData", "Iterator", "IsPaused", "SuccessEvent", 
     ("LockExpirationTime" > CAST(strftime('%s','now') || substr(strftime('%f','now'),4) AS INTEGER)) as "Locked", "LockId"
     FROM ${escapeId(replicationStateTableName)}`);

  if (rows.length > 0) {
    const row = rows[0];
    let lastEvent = null;

    if (row.SuccessEvent != null) {
      lastEvent = JSON.parse(row.SuccessEvent);
    }

    return {
      statusAndData: {
        status: row.Status,
        data: row.StatusData != null ? JSON.parse(row.StatusData) : null
      },
      paused: row.IsPaused !== 0,
      iterator: row.Iterator != null ? JSON.parse(row.Iterator) : null,
      successEvent: lastEvent,
      locked: !!row.Locked,
      lockId: row.lockId
    };
  } else {
    return (0, _eventstoreBase.getInitialReplicationState)();
  }
};

var _default = getReplicationState;
exports.default = _default;
//# sourceMappingURL=get-replication-state.js.map